dovecot-2.1-pigeonhole: LDA Sieve plugin: renamed sieve_global_p...

pigeonhole at rename-it.nl pigeonhole at rename-it.nl
Sat Jan 7 17:01:15 EET 2012


details:   http://hg.rename-it.nl/dovecot-2.1-pigeonhole/rev/bd5cffe2ed95
changeset: 1592:bd5cffe2ed95
user:      Stephan Bosch <stephan at rename-it.nl>
date:      Sat Jan 07 16:01:10 2012 +0100
description:
LDA Sieve plugin: renamed sieve_global_path setting to sieve_default for clarity.
Old name is now deprecated.
Support for the even older global_script_path name for this setting is dropped.

diffstat:

 INSTALL                                  |  22 ++++++++++++----------
 README                                   |   2 +-
 doc/example-config/conf.d/90-sieve.conf  |   2 +-
 src/plugins/lda-sieve/lda-sieve-plugin.c |   8 ++++----
 4 files changed, 18 insertions(+), 16 deletions(-)

diffs (89 lines):

diff -r 83fc2f6edefa -r bd5cffe2ed95 INSTALL
--- a/INSTALL	Sat Jan 07 12:42:01 2012 +0100
+++ b/INSTALL	Sat Jan 07 16:01:10 2012 +0100
@@ -87,11 +87,15 @@
  sieve = ~/.dovecot.sieve
    The path to the user's main active script. 
  
- sieve_global_path
-   A path to a global sieve script file, which gets executed ONLY if user's 
-   private Sieve script doesn't exist, e.g. /var/lib/dovecot/default.sieve. Be 
-   sure to pre-compile this script manually using the sievec command line tool,
-   as explained in the README file. 
+ sieve_default = 
+   The path to the default personal sieve script file, which gets executed ONLY
+   if user's private Sieve script does no exist, e.g.
+   /var/lib/dovecot/default.sieve. This is usually a global script, so sure to
+   pre-compile this script manually using the sievec command line tool, as
+   explained in the README file.
+
+ sieve_global_path =
+   This is the DEPRECATED former name of the sieve_default setting.
 
  sieve_global_dir =
    Directory for :global include scripts for the Sieve include extension. 
@@ -144,7 +148,7 @@
 
   # If the user has no personal active script (i.e. if the file 
   # indicated in sieve= does not exist), use this one:
-  sieve_global_path = /var/lib/dovecot/sieve/default.sieve
+  sieve_default = /var/lib/dovecot/sieve/default.sieve
 
   # The include extension fetches the :personal scripts from this 
   # directory. When ManageSieve is used, this is also where scripts 
@@ -207,10 +211,8 @@
 Pigeonhole's Sieve interpreter allows executing multiple Sieve scripts 
 sequentially. The extra scripts can be executed before and after the user's
 private script. For example, this allows executing global Sieve policies before
-the user's script. This is not possible using the sieve_global_path setting, 
-because that is only used as a default when the user's private script does not
-exist. The following settings in the plugin section of the Dovecot config file
-control the execution sequence:
+the user's script. The following settings in the plugin section of the Dovecot
+config file control the execution sequence:
 
  sieve_before =
    Path to a script file or a directory containing script files that need to be
diff -r 83fc2f6edefa -r bd5cffe2ed95 README
--- a/README	Sat Jan 07 12:42:01 2012 +0100
+++ b/README	Sat Jan 07 16:01:10 2012 +0100
@@ -209,7 +209,7 @@
 
 sievec /var/lib/dovecot/sieve/global/
 
-This is necessary for scripts listed in the sieve_global_path, sieve_before and
+This is necessary for scripts listed in the sieve_default, sieve_before and
 sieve_after settings. For global scripts that are only included in other scripts
 using the include extension, this step is not necessary, since included scripts
 are incorporated into the binary produced for the main script located in a
diff -r 83fc2f6edefa -r bd5cffe2ed95 doc/example-config/conf.d/90-sieve.conf
--- a/doc/example-config/conf.d/90-sieve.conf	Sat Jan 07 12:42:01 2012 +0100
+++ b/doc/example-config/conf.d/90-sieve.conf	Sat Jan 07 16:01:10 2012 +0100
@@ -16,7 +16,7 @@
   # command line tool.
   # --> See sieve_before fore executing scripts before the user's personal
   #     script.
-  #sieve_global_path = /var/lib/dovecot/sieve/default.sieve
+  #sieve_default = /var/lib/dovecot/sieve/default.sieve
 
   # Directory for :personal include scripts for the include extension. This
   # is also where the ManageSieve service stores the user's scripts.
diff -r 83fc2f6edefa -r bd5cffe2ed95 src/plugins/lda-sieve/lda-sieve-plugin.c
--- a/src/plugins/lda-sieve/lda-sieve-plugin.c	Sat Jan 07 12:42:01 2012 +0100
+++ b/src/plugins/lda-sieve/lda-sieve-plugin.c	Sat Jan 07 16:01:10 2012 +0100
@@ -202,11 +202,11 @@
 {
 	const char *script_path;
 
-	/* Use global script path, if one exists */
-	script_path = mail_user_plugin_getenv(user, "sieve_global_path");
-	if (script_path == NULL) {
+	/* Use default script path, if one exists */
+	script_path = mail_user_plugin_getenv(user, "sieve_default");
+	if ( script_path == NULL ) {
 		/* For backwards compatibility */
-		script_path = mail_user_plugin_getenv(user, "global_script_path");
+		script_path = mail_user_plugin_getenv(user, "sieve_global_path");
 	}
 
 	return script_path;


More information about the dovecot-cvs mailing list